@@ -3,6 +3,14 @@ WowMySQL Python SDK
 Official client library for WowMySQL REST API v2
 """
 
+from .auth import (
+    ProjectAuthClient,
+    AuthResponse,
+    AuthSession,
+    AuthUser,
+    TokenStorage,
+    MemoryTokenStorage,
+)
 from .client import WowMySQLClient, WowMySQLError
 from .table import Table, QueryBuilder
 from .types import (
@@ -23,11 +31,12 @@ from .storage import (
     StorageLimitExceededError,
 )
 
-__version__ = "0.2.0"
+__version__ = "0.4.1"
 __all__ = [
     # Database Client
     "WowMySQLClient",
     "WowMySQLError",
+    "ProjectAuthClient",
     "Table",
     "QueryBuilder",
     # Types
@@ -45,5 +54,10 @@ __all__ = [
     "StorageFile",
     "StorageError",
     "StorageLimitExceededError",
+    # Auth
+    "AuthUser",
+    "AuthSession",
+    "AuthResponse",
+    "TokenStorage",
+    "MemoryTokenStorage",
 ]
-
